@@ -122,9 +122,7 @@ yf_get <- function(tickers,
                    be_quiet = FALSE) {
 
   # check for internet
-  if (!pingr::is_online()) {
-    stop("Can't find an active internet connection...")
-  }
+  check_internet()
 
   # check cache folder
   if ((do_cache) & (!dir.exists(cache_folder))) dir.create(cache_folder,
@@ -197,14 +195,14 @@ yf_get <- function(tickers,
 
   # disable dplyr group message and respect user choice
   # will be null if options is not set
-  default_dplyr_summ <- options("dplyr.summarise.inform")[[1]]
+  default_dplyr_sum <- options("dplyr.summarise.inform")[[1]]
 
   # disable and enable at end with on exit
   options(dplyr.summarise.inform = FALSE)
 
   on.exit({
-    if (is.logical(default_dplyr_summ)) {
-      options(dplyr.summarise.inform = default_dplyr_summ)
+    if (is.logical(default_dplyr_sum)) {
+      options(dplyr.summarise.inform = default_dplyr_sum)
     }
   })
 
@@ -538,7 +536,7 @@ yf_get <- function(tickers,
       cache_files <- list.files(cache_folder, full.names = TRUE)
       size_files <- sum(sapply(cache_files, file.size))
 
-      size_str <- humanize::natural_size(size_files)
+      size_str <- natural_size(size_files)
       n_files <- length(list.files(cache_folder))
 
       cli::cli_alert_info("Using {size_str} at {cache_folder} for {n_files} cache files")
